@@ -54,13 +54,15 @@ class BaseFunctions(SalureConnect):
         """
         url = f"{self.base_url}/{uri}?$filter={filter}" if filter is not None else f"{self.base_url}/{uri}"
         response = requests.request("GET", f"{url}", headers=self.headers, data={})
-        response.raise_for_status()
         if self.debug:
             print(response.text)
-        with open(f"{self.data_dir}/{uri}.xml", 'wb') as file:
-            file.write(response.content)
-        df = pdx.read_xml(f"{self.data_dir}/{uri}.xml", [xml_root], root_is_rows=False)
-        df = df.pipe(pdx.fully_flatten).reset_index(drop=True)
+        if response.text == '':
+            df = pd.DataFrame()
+        else:
+            with open(f"{self.data_dir}/{uri}.xml", 'wb') as file:
+                file.write(response.content)
+            df = pdx.read_xml(f"{self.data_dir}/{uri}.xml", [xml_root], root_is_rows=False)
+            df = df.pipe(pdx.fully_flatten).reset_index(drop=True)
         return df
 
     def post_data(self, uri: str, data: dict, filter: str = None, return_key: str = None):
@@ -74,7 +76,6 @@ class BaseFunctions(SalureConnect):
         """
         url = f"{self.base_url}/{uri}?$filter={filter}" if filter is not None else f"{self.base_url}/{uri}"
         response = requests.request("POST", url, headers=self.headers, data=json.dumps(data))
-        response.raise_for_status()
         if self.debug:
             return response
         # Don't use raise_for_status() here because the errors from SAP will come in XML format which can be parsed here
