@@ -1,9 +1,10 @@
 from salure_helpers.sap.base_functions import BaseFunctions
+from salure_helpers.sap.get_endpoints import GetEndpoints
 from salure_helpers.sap.delimit_endpoints import DelimitEndpoints
 from salure_helpers.sap.post_endpoints import PostEndpoints
 
 
-class SAP(BaseFunctions, PostEndpoints, DelimitEndpoints):
+class SAP(BaseFunctions, GetEndpoints, PostEndpoints, DelimitEndpoints):
     def __init__(self, label: str, data_dir: str, certificate_file: str = None, key_file: str = None, debug: bool = False):
         """
         Inherit all the child classes into this one class. Users can now use all the functions from the child classes just by initializing this class.
@@ -13,6 +14,7 @@ class SAP(BaseFunctions, PostEndpoints, DelimitEndpoints):
         :param key_file: The key file in bytes format: open(file, 'rb')
         """
         BaseFunctions.__init__(self, label, data_dir, certificate_file, key_file, debug)
+        GetEndpoints.__init__(self, label, data_dir, certificate_file, key_file, debug)
         PostEndpoints.__init__(self, label, data_dir, certificate_file, key_file, debug)
         DelimitEndpoints.__init__(self, label, data_dir, certificate_file, key_file, debug)
 
